@@ -758,7 +758,7 @@ def form_handler(
     around the form. This generic view can be used for them.
     """
     from django.shortcuts import render_to_response
-    is_ajax = require.is_ajax() or ajax or request.REQUEST.get("json") == "true"
+    is_ajax = request.is_ajax() or ajax or request.REQUEST.get("json")=="true"
     if login_url is None: 
         login_url = getattr(settings, "LOGIN_URL", "/login/")
     if callable(require_login): 
@@ -1236,3 +1236,9 @@ def object_list(request, queryset, paginate_by=None, page=None,
     t = template_loader.get_template(template_name)
     return HttpResponse(t.render(c), mimetype=mimetype)
 # }}} 
+
+# ip_shell # {{{ 
+def ip_shell():
+    from IPython import Shell
+    Shell.IPShellEmbed()()
+# }}} 
